Class: Google::Apis::CloudresourcemanagerV2beta1::ProjectCreationStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudresourcemanager_v2beta1/classes.rb,
lib/google/apis/cloudresourcemanager_v2beta1/representations.rb,
lib/google/apis/cloudresourcemanager_v2beta1/representations.rb

Overview

A status object which is used as the metadata field for the Operation returned by CreateProject. It provides insight for when significant phases of Project creation have completed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectCreationStatus

Returns a new instance of ProjectCreationStatus.



965
966
967
# File 'lib/google/apis/cloudresourcemanager_v2beta1/classes.rb', line 965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Creation time of the project creation workflow. Corresponds to the JSON property createTime

Returns:

  • (String)


950
951
952
# File 'lib/google/apis/cloudresourcemanager_v2beta1/classes.rb', line 950

def create_time
  @create_time
end

#gettableBoolean Also known as: gettable?

True if the project can be retrieved using GetProject. No other operations on the project are guaranteed to work until the project creation is complete. Corresponds to the JSON property gettable

Returns:

  • (Boolean)


956
957
958
# File 'lib/google/apis/cloudresourcemanager_v2beta1/classes.rb', line 956

def gettable
  @gettable
end

#readyBoolean Also known as: ready?

True if the project creation process is complete. Corresponds to the JSON property ready

Returns:

  • (Boolean)


962
963
964
# File 'lib/google/apis/cloudresourcemanager_v2beta1/classes.rb', line 962

def ready
  @ready
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



970
971
972
973
974
# File 'lib/google/apis/cloudresourcemanager_v2beta1/classes.rb', line 970

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @gettable = args[:gettable] if args.key?(:gettable)
  @ready = args[:ready] if args.key?(:ready)
end